@@ -4,15 +4,15 @@ import base64
 import os
 from abc import ABC, abstractmethod
 from pathlib import Path
-from typing import Dict, List, Optional, Union, cast
+from typing import List, Mapping, Optional, Union, cast
 
 import toml
 from dotenv import load_dotenv
 from outcome.utils import env
 
 ValidPath = Union[str, Path]
-ValidConfigType = Union[str, int, float, bool, list]
-ConfigDict = Dict[str, ValidConfigType]
+ValidConfigType = Union[str, int, float, bool, List['ValidConfigType']]
+ConfigDict = Mapping[str, ValidConfigType]
 
 
 class Sentinel:
@@ -61,9 +61,9 @@ class EnvBackend(ConfigBackend):
 
 class DefaultBackend(ConfigBackend):
 
-    defaults: Dict[str, ValidConfigType]
+    defaults: Mapping[str, ValidConfigType]
 
-    def __init__(self, defaults: Dict[str, ValidConfigType]):
+    def __init__(self, defaults: Mapping[str, ValidConfigType]):
         self.defaults = defaults
 
     def get(self, key: str) -> ValidConfigType:
@@ -77,9 +77,9 @@ class TomlBackend(ConfigBackend):
 
     path: Optional[ValidPath]
     config: Optional[ConfigDict]
-    aliases: Optional[Dict[str, str]]
+    aliases: Optional[Mapping[str, str]]
 
-    def __init__(self, path: Optional[ValidPath] = None, aliases: Optional[Dict[str, str]] = None):
+    def __init__(self, path: Optional[ValidPath] = None, aliases: Optional[Mapping[str, str]] = None):
         self.path = path
         self.aliases = aliases
         self.config = None
@@ -100,9 +100,11 @@ class TomlBackend(ConfigBackend):
         self.config = self.get_config(self.path, self.aliases)
 
     @classmethod
-    def get_config(cls, path: ValidPath, aliases: Optional[Dict[str, str]] = None) -> Dict[str, ValidConfigType]:
+    def get_config(  # noqa: WPS615
+        cls, path: ValidPath, aliases: Optional[Mapping[str, str]] = None,
+    ) -> Mapping[str, ValidConfigType]:
         config = toml.load(path)
-        config_flattened = cls.flatten_keys(config)
+        config_flattened = dict(cls.flatten_keys(config))
 
         if aliases:
             for original, alias in aliases.items():
@@ -111,16 +113,16 @@ class TomlBackend(ConfigBackend):
         return config_flattened
 
     @classmethod
-    def flatten_keys(cls, value: object, key: Optional[str] = None) -> Dict[str, ValidConfigType]:
+    def flatten_keys(cls, value: object, key: Optional[str] = None) -> Mapping[str, ValidConfigType]:
         if not isinstance(value, dict):
             if not key:
                 raise Exception('Value cannot be a non-dict without a key')
 
             assert isinstance(value, (str, int, float, bool, list))
-            return {key.upper(): value}
+            return {key.upper(): cast(ValidConfigType, value)}
 
         flattened = {}
-        value = cast(Dict[str, object], value)
+        value = cast(Mapping[str, object], value)
 
         for k, v in value.items():
             prefix = (f'{key}_' if key else '').upper()
@@ -166,8 +168,8 @@ class Config:  # pragma: only-covered-in-unit-tests
     def __init__(
         self,
         path: Optional[ValidPath] = None,
-        aliases: Optional[Dict[str, str]] = None,
-        defaults: Optional[Dict[str, ValidConfigType]] = None,
+        aliases: Optional[Mapping[str, str]] = None,
+        defaults: Optional[Mapping[str, ValidConfigType]] = None,
     ) -> None:
         """Initialize the class with an optional config file and set of aliases.
 
@@ -185,8 +187,8 @@ class Config:  # pragma: only-covered-in-unit-tests
 
         Arguments:
             path (ValidPath, optional): The path to the config file.
-            aliases (Dict[str, str], optional): The aliasing dict.
-            defaults (Dict[str, ValidConfigType], optional): A dict of hardcoded values
+            aliases (Mapping[str, str], optional): The aliasing dict.
+            defaults (Mapping[str, ValidConfigType], optional): A dict of hardcoded values
         """
         self.backends = [EnvBackend()]
         if path:
