@@ -25,5 +25,6 @@ def load_obj(objspec: str, default_obj: Optional[str] = None):
 def load_module(name: str, path: str):  # pragma: no cover
     spec = util.spec_from_file_location(name, path)
     mod = util.module_from_spec(spec)
-    spec.loader.exec_module(mod)
+    assert spec.loader
+    spec.loader.exec_module(mod)  # type: ignore
     return mod
